Usage
findMotif(all.seq, category, weights = rep(1, length(all.seq)),
start.width=6,min.cutoff=5, min.ratio=1.3,
min.frac=0.01, both.strand=TRUE, flank=2, max.motif=5,
mask=TRUE,other.data=NULL, start.nmer=NULL,
enriched.only=F,n.bootstrap = 5, bootstrap.pvalue=0.1,is.parallel =
TRUE,mc.cores = 4,min.info=10,max.width=15,discretize=TRUE)
Arguments
all.seq
DNAStringSet; foreground and background sequences.
category
numeric vector; specify which sequences are
foreground (with value 1), and background (value 0).
weights
numeric vector: the weights for all sequences. Default: 1
start.width
logical; the width for enumerating seed patterns
min.cutoff
numeric; the score cutoff required for seed selection. All
scores are negative, the lower the better.
min.ratio
numeric; the minimum fold change of motif occurences
in foreground vs background.
min.frac
numeric; the minimum fraction of fg/bg sequences
containing the candidate motifs
both.strand
logical; if true, search both strands
flank
integer; the length for step-wise pattern extension at
both ends on candidate motifs
max.motif
integer; the maximum number of output motifs
mask
logical; if true, mask previous motifs when searching for
the next motif
other.data
if not NULL, a matrix with additional terms for the regression
model for bias adjustment
start.nmer
if not NULL, a matrix with counts for user specified seed pattern in
each sequence
enriched.only
logical; if true, only predict enriched motif
n.bootstrap
integer; the number of bootstrapping tests to
estimate score variance
bootstrap.pvalue
numeric: the bootstrap t.test pvalues to
determine the significance of improvement
is.parallel
logical;if true, runs in parallel mode, and requires
"parallel" library
mc.cores
integer; the number of CPUs for paralel run
min.info
minimal information content for the motif to prevent
it from being too degenerate
max.width
maximum width of the motif for extension
discretize
logical default TRUE